@@ -274,6 +274,23 @@ audio_init(void)
     return -1;
   }
 
+  /* for mp3lame codec's rate */
+  if (out_acodec == ACODEC_MP3) {
+    out_rate = acodec_encode_get_out_rate();
+    if (out_rate != last_in_rate) {
+      resample_flag = 1;
+    }
+    if (out_rate != out_file->rate) {
+      acodec_encode_quit();
+      if (acodec_encode_init(out_file->acodec, out_rate, out_channels, out_bits) != ACODEC_OK) {
+        fprintf(stderr, "audio_init: acodec_encode_init failed\n");
+        audio_disable = 1;
+        return -1;
+      }
+    }
+    out_file->rate = out_rate;
+  }
+
   switch (out_acodec) {
     case ACODEC_PCM_LE:
       out_file->format = out_format = 0x1;
